.. _biomechanics_tutorial:

======================
Biomechanics Tutorials
======================

These tutorials provide a comprehensive guide on using SymPy for biomechanical
simulations and analysis. We cover various models, including a human arm moving
a lever, forces produced by muscles, and tendons using Hill-type muscle models.

In these tutorials, you can expect:

- Model description: Detailed explanation of each biomechanical model.
- Variables and Kinematics: Definition of necessary variables and kinematics
  equations essential for modeling.
- Modeling: Step-by-step process of constructing the biomechanical models.
- Equations of Motion: Derivation and analysis of the equations of motion for
  the systems.

.. toctree::
   :maxdepth: 2

   biomechanics.rst
   biomechanical-model-example.rst
